#
# Author:: Frédéric Nowak (<frederic.nowak@alphard.io>)
# Cookbook Name:: alphard-cron
# Definition:: cron_restart
#
# Copyright 2016, Hydra Technologies, Inc
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

define :cron_restart,
       :expression => '* * * * *',
       :minute => nil, :hour => nil, :weekday => nil, :day => nil, :month => nil,
       :randomized => false, :delay => 300, :enabled => true do

  # Defines variables
  name = params[:name]

  cron_name = "cron_restart_#{name}"
  cron_log_directory = '/var/log/chef/cron'
  cron_log_file = "#{cron_log_directory}/#{cron_name}.log"

  expression = params[:expression]
  expression_array = expression.split(' ')

  minute = params[:minute]
  if minute.nil?
    minute = expression_array[0]
  end

  hour = params[:hour]
  if hour.nil?
    hour = expression_array[1]
  end

  weekday = params[:weekday]
  if weekday.nil?
    weekday = expression_array[2]
  end

  day = params[:day]
  if day.nil?
    day = expression_array[3]
  end

  month = params[:month]
  if month.nil?
    month = expression_array[4]
  end

  enabled = params[:enabled]
  randomized = params[:randomized]
  delay = params[:delay]
  command = "service #{name} restart >> #{cron_log_file}"
  if randomized
    random_delay = rand(0..delay)
    command = (randomized ? "sleep #{random_delay}s ; " : '') + command
  end

  # Creates log directory if it doesn't exist
  directory cron_log_directory do
    owner node['alphard']['cron']['user']
    group node['alphard']['cron']['group']
    mode '0644'
    action :create
  end

  # Create log file if it doesn't exist
  file cron_log_file do
    owner node['alphard']['cron']['user']
    group node['alphard']['cron']['group']
    mode '0644'
    action :create_if_missing
  end

  # Schedules service restart in cron
  cron cron_name do
    user node['alphard']['cron']['user']
    command command
    minute minute
    hour hour
    weekday weekday
    day day
    month month
    action enabled ? :create : :delete
  end

end